@@ -1,18 +1,62 @@
 # -*- coding: utf-8 -*-
+import os
 import unittest
+import zipfile
 
 import xml.etree.ElementTree as ET
 
-from dwca.descriptors import SectionDescriptor, ArchiveDescriptor
+from dwca.descriptors import DataFileDescriptor, ArchiveDescriptor
 from dwca.darwincore.utils import qualname as qn
 from dwca.read import DwCAReader
 
 from .helpers import (BASIC_ARCHIVE_PATH, EXTENSION_ARCHIVE_PATH,
-                      MULTIEXTENSIONS_ARCHIVE_PATH)
+                      MULTIEXTENSIONS_ARCHIVE_PATH, SIMPLE_CSV)
 
 
-class TestSectionDescriptor(unittest.TestCase):
-    """Unit tests for SectionDescriptor class."""
+class TestDataFileDescriptor(unittest.TestCase):
+    """Unit tests for DataFileDescriptor class."""
+
+    def test_init_from_file(self):
+        """ Ensure a DataFileDescriptor can be constructed directly from a CSV file.
+
+        This is necessary for archives sans metafile.
+        """
+        with zipfile.ZipFile(SIMPLE_CSV, 'r') as archive:
+            datafile_path = archive.extract('0008333-160118175350007.csv')
+
+            d = DataFileDescriptor.make_from_file(datafile_path)
+            # Check basic metadata with the file
+            self.assertIsNone(d.raw_element)
+            self.assertTrue(d.represents_corefile)
+            self.assertFalse(d.represents_extension)
+            self.assertIsNone(d.type)
+            self.assertEqual(d.file_location, '0008333-160118175350007.csv')
+            self.assertEqual(d.file_encoding, 'utf-8')
+            self.assertEqual(d.lines_terminated_by, "\n")
+            self.assertEqual(d.fields_terminated_by, "\t")
+            self.assertEqual(d.fields_enclosed_by, '"')
+
+            # Some checks on fields...
+
+            # A few fields are checked
+            expected_fields = ({'default': None, 'index': 0, 'term': 'gbifid'},
+                               {'default': None, 'index': 3, 'term': 'kingdom'})
+
+            for ef in expected_fields:
+                self.assertTrue(ef in d.fields)
+
+            # In total, there are 42 fields in this data file
+            self.assertEqual(len(d.fields), 42)
+
+            # No fields should have a default value (there's no metafile to set it!)
+            for f in d.fields:
+                self.assertIsNone(f['default'])
+
+            # Ensure .terms is also set:
+            self.assertEqual(len(d.terms), 42)
+
+            # Cleanup extracted file
+            os.remove(datafile_path)
 
     def test_lines_to_ignore(self):
         # With explicit "0"
@@ -27,7 +71,7 @@ class TestSectionDescriptor(unittest.TestCase):
         </core>
         """
 
-        core_descriptor = SectionDescriptor(ET.fromstring(metaxml_section))
+        core_descriptor = DataFileDescriptor.make_from_metafile_section(ET.fromstring(metaxml_section))
 
         self.assertEqual(core_descriptor.lines_to_ignore, 0)
 
@@ -43,7 +87,7 @@ class TestSectionDescriptor(unittest.TestCase):
         </core>
         """
 
-        core_descriptor = SectionDescriptor(ET.fromstring(metaxml_section))
+        core_descriptor = DataFileDescriptor.make_from_metafile_section(ET.fromstring(metaxml_section))
 
         self.assertEqual(core_descriptor.lines_to_ignore, 1)
 
@@ -59,7 +103,7 @@ class TestSectionDescriptor(unittest.TestCase):
         </core>
         """
 
-        core_descriptor = SectionDescriptor(ET.fromstring(metaxml_section))
+        core_descriptor = DataFileDescriptor.make_from_metafile_section(ET.fromstring(metaxml_section))
 
         self.assertEqual(core_descriptor.lines_to_ignore, 0)
 
@@ -79,10 +123,10 @@ class TestSectionDescriptor(unittest.TestCase):
         </core>
         """
 
-        core_descriptor = SectionDescriptor(ET.fromstring(metaxml_section))
+        core_descriptor = DataFileDescriptor.make_from_metafile_section(ET.fromstring(metaxml_section))
 
         self.assertEqual(core_descriptor.file_location, "occurrence.txt")
-        self.assertEqual(core_descriptor.encoding, "utf-8")
+        self.assertEqual(core_descriptor.file_encoding, "utf-8")
         # TODO: Also test .lines_terminated_by and .fields_terminated_by
         # (this seems a bit tricky, and it's already tested indirectly - many things would fail
         # without them)
@@ -103,7 +147,7 @@ class TestSectionDescriptor(unittest.TestCase):
         </core>
         """
 
-        core_descriptor = SectionDescriptor(ET.fromstring(metaxml_section))
+        core_descriptor = DataFileDescriptor.make_from_metafile_section(ET.fromstring(metaxml_section))
 
         # .fields is supposed to return a list of dicts like those
         expected_fields = (
@@ -175,7 +219,7 @@ class TestSectionDescriptor(unittest.TestCase):
         </core>
         """
 
-        core_descriptor = SectionDescriptor(ET.fromstring(metaxml_section))
+        core_descriptor = DataFileDescriptor.make_from_metafile_section(ET.fromstring(metaxml_section))
 
         expected_headers_core = ['id',
                                  'http://rs.tdwg.org/dwc/terms/scientificName',
@@ -201,7 +245,7 @@ class TestSectionDescriptor(unittest.TestCase):
             <field index="5" term="http://rs.tdwg.org/dwc/terms/genus"/>
         </core>
         """
-        core_descriptor = SectionDescriptor(ET.fromstring(metaxml_section))
+        core_descriptor = DataFileDescriptor.make_from_metafile_section(ET.fromstring(metaxml_section))
 
         expected_headers_core = ['id',
                                  'http://rs.tdwg.org/dwc/terms/order',
@@ -230,7 +274,7 @@ class TestSectionDescriptor(unittest.TestCase):
         </extension>
         """
 
-        ext_descriptor = SectionDescriptor(ET.fromstring(ext_section))
+        ext_descriptor = DataFileDescriptor.make_from_metafile_section(ET.fromstring(ext_section))
 
         self.assertEqual(ext_descriptor.raw_element.tag, 'extension')
         self.assertEqual(ext_descriptor.raw_element.get('encoding'), 'utf-8')
@@ -241,7 +285,7 @@ class TestSectionDescriptor(unittest.TestCase):
         with DwCAReader(BASIC_ARCHIVE_PATH) as dwca:
             core_descriptor = dwca.descriptor.core
             self.assertTrue(core_descriptor.represents_corefile)
-            self.assertFalse(core_descriptor.represents_extensionfile)
+            self.assertFalse(core_descriptor.represents_extension)
 
         ext_section = """
         <extension encoding="utf-8" fieldsTerminatedBy="\t" linesTerminatedBy="\n"
@@ -255,9 +299,9 @@ class TestSectionDescriptor(unittest.TestCase):
         """
 
         # 2. And with extension
-        ext_descriptor = SectionDescriptor(ET.fromstring(ext_section))
+        ext_descriptor = DataFileDescriptor.make_from_metafile_section(ET.fromstring(ext_section))
         self.assertFalse(ext_descriptor.represents_corefile)
-        self.assertTrue(ext_descriptor.represents_extensionfile)
+        self.assertTrue(ext_descriptor.represents_extension)
 
     def test_exposes_coreid_index_of_extensions(self):
         ext_section = """
@@ -270,13 +314,12 @@ class TestSectionDescriptor(unittest.TestCase):
         </extension>
         """
 
-        ext_descriptor = SectionDescriptor(ET.fromstring(ext_section))
+        ext_descriptor = DataFileDescriptor.make_from_metafile_section(ET.fromstring(ext_section))
 
         self.assertEqual(ext_descriptor.coreid_index, 0)
 
         # ... but it doesn't have .id_index (only for core!)
-        with self.assertRaises(AttributeError):
-            ext_descriptor.id_index
+        self.assertIsNone(ext_descriptor.id_index)
 
     def test_exposes_id_index_of_core(self):
         metaxml_section = """
@@ -294,13 +337,12 @@ class TestSectionDescriptor(unittest.TestCase):
         </core>
         """
 
-        core_descriptor = SectionDescriptor(ET.fromstring(metaxml_section))
+        core_descriptor = DataFileDescriptor.make_from_metafile_section(ET.fromstring(metaxml_section))
 
         self.assertEqual(core_descriptor.id_index, 0)
 
         # ... but it doesn't have .coreid_index (only for extensions!)
-        with self.assertRaises(AttributeError):
-            core_descriptor.coreid_index
+        self.assertIsNone(core_descriptor.coreid_index)
 
     def test_exposes_core_type(self):
         """Test that it exposes the Archive Core Type as type"""
@@ -345,7 +387,7 @@ class TestArchiveDescriptor(unittest.TestCase):
 
     def test_exposes_coredescriptor(self):
         with DwCAReader(BASIC_ARCHIVE_PATH) as basic_dwca:
-            self.assertIsInstance(basic_dwca.descriptor.core, SectionDescriptor)
+            self.assertIsInstance(basic_dwca.descriptor.core, DataFileDescriptor)
 
     def test_exposes_extensions_2ext(self):
         all_metaxml = """
