@@ -299,6 +299,7 @@ class TestDwCAReader(unittest.TestCase):
             f = open(path_to_occ)
             content = f.read()
             self.assertTrue(content.startswith("id"))
+            f.close()
 
         with DwCAReader(DIRECTORY_ARCHIVE_PATH) as dwca:
             # Also check if the archive is a directory
@@ -738,13 +739,15 @@ class TestDwCAReader(unittest.TestCase):
             self.assertEqual(v, 'en')
 
     def test_unknown_archive_format(self):
-        """ Ensure InvalidArchive is raised when passed file is not a .zip not .tgz."""
-        invalid_origin_file = tempfile.NamedTemporaryFile()
+        """ Ensure InvalidArchive is raised when passed file is not a .zip nor .tgz."""
+        invalid_origin_file = tempfile.NamedTemporaryFile(delete=False)
 
         with self.assertRaises(InvalidArchive):
             with DwCAReader(invalid_origin_file.name):
                 pass
 
+        invalid_origin_file.close()
+
 
 if __name__ == "__main__":
     unittest.main()
